Stan Math Library: stan/math/prim/scal/meta/container_view.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
container_view.hpp File Reference
`#include <stan/math/prim/scal/meta/scalar_type.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Classes
class | stan::math::container_view< T1, T2 >
| Primary template class for container view of array y with same structure as T1 and size as x. More...
struct | stan::math::dummy
| Empty struct for use in boost::condtional<is_constant_struct<T1>::value, T1, dummy>::type as false condtion for safe indexing. More...
class | stan::math::container_view< dummy, T2 >
| Dummy type specialization, used in conjunction with struct dummy as described above. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.